#!/usr/bin/python3
# coding: utf-8
#
#       convertToInpDDialog.py
#
#       fistr2abaqus.py変換用のinpファイル名を取得する
#
#   25/01/04    新規作成
#      01/10    refine
#


import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk, GLib
import os, sys
import showContentsDDialog

localeDir = os.getenv("LOCALE_DIR")

ls = "\n"

#----------------------
#  getInpName class
#----------------------
class getInpName:
    """ fistr2abaqus.py変換の為のinpファイル名を取得する"""

    def __init__(self, inpName, funcOk=[], parent=None):
        self.builder = Gtk.Builder()
        path = os.getenv("easyIstrPath") + os.sep + "glade" + os.sep
        self.builder.add_from_file(path + "convertToInpDDialog.glade")
        self.dialog = self.builder.get_object("dialog1")
        self.dialog.set_transient_for(parent)
        self.dialog.connect("delete-event", self.close)
        self.builder.connect_signals(self)
        self.setGtkObject()
        self.dialog.set_title("fistr2abaqus.py")
        self.funcOk = funcOk
        self.inpName = ""
        self.entry_inpName.set_text(inpName)

    def setGtkObject(self):
        """ GUIのobject名を取得する"""
        self.label_topMess = self.builder.get_object("label_topMess")
        self.label_conts = self.builder.get_object("label_conts")
        self.label_setInpFile = self.builder.get_object("label_setInpFile")
        self.label_inpName = self.builder.get_object("label_inpName")
        self.entry_inpName = self.builder.get_object("entry_inpName")
        self.button_showDetail = self.builder.get_object("button_showDetail")
        self.button_convert = self.builder.get_object("button_convert")
        self.button_cancel = self.builder.get_object("button_cancel")
        #文字を設定
        mess = _("<変換対象>") + ls
        mess += _("  !NODE, !ELEMENT, !EGROUP, !SGROUP, !NGROUP,") + ls
        mess += _("  !SECTION, !MATERIAL, !EQUATION,") + ls
        mess += _("  !BOUNDARY, !CLOAD, !CFLUX, !DLOAD-S, !FIXTEMP") + ls
        mess += _("<mesheType>") + ls
        mess += _("  341, 342, 351, 352, 361, 362, 611,") + ls
        mess += _("  731, 732, 741, 742")
        self.label_conts.set_text(mess)
        self.label_topMess.set_text(_("cnt,mshファイルをCalculixの inp ファイルに変換"))
        self.label_setInpFile.set_text(_("変換ファイル名を入力"))
        self.label_inpName.set_text(_("inp名:"))
        self.button_showDetail.get_child().set_text(_("変換内容の詳細表示..."))
        self.button_convert.get_child().set_text(_("変換開始"))
        self.button_cancel.get_child().set_text(_("キャンセル"))


    def show(self):
        self.dialog.show()

    def close(self, *args):
        self.dialog.close()

    def onCancel(self, event):
        self.close()

    def onShowDetail(self, event):
        self.showDetail()

    def onActivate(self, event):
        self.onOk(event)

    def onOk(self, event):
        inpName = self.entry_inpName.get_text()
        self.close()
        if len(self.funcOk) > 0:
            funcName = self.funcOk[0]
            funcArgs = [inpName] + self.funcOk[1:]
            GLib.timeout_add(100, funcName, *funcArgs)

    #
    #  showDetail
    #-------------
    def showDetail(self):
        """ 変換内容の詳細を表示する"""
        #実行file名を取得
        fileName = os.getenv("easyIstrPath") + os.sep + "bin" + os.sep + "fistr2abaqus.py"
        #変換内容を実行fileから取得
        f = open(fileName, encoding="utf-8"); lines = f.readlines(); f.close()
        contLines = []
        for i in range(2, len(lines), 1):
            line = lines[i]
            if line[:len("#--------")] == "#--------":
                break
            contLines += [line]
        conts = "".join(contLines)
        dialog = showContentsDDialog.showMessage(conts, parent=self.dialog)
        dialog.show()



if __name__ == "__main__":
    import gettext
    #gettext.install("app") # replace with the appropriate catalog name
    _ = gettext.gettext
    dialog = getInpName()
    dialog.show()
    Gtk.main()
